Package: rim
Type: Package
Title: Interface to 'Maxima', Enabling Symbolic Computation
Version: 0.6.4
Date: 2023-08-24
Authors@R: c(
    person("Eric", "Stemmler", email = "stemmler.eric@gmail.com", role = c("aut", "cre")),
    person("Kseniia", "Shumelchyk", email = "shumelchyk@gmail.com", role = c("aut")),
    person("Hans W.", "Borchers", email = "hwborchers@googlemail.com", role = c("aut")))
Description: An interface to the powerful and fairly complete computer algebra system 'Maxima'.
    It can be used to start and control 'Maxima' from within R by entering 'Maxima' commands. 
    Results from 'Maxima' can be parsed and evaluated in R. 
    It facilitates outputting results from 'Maxima' in 'LaTeX' and 'MathML'. 
    2D and 3D plots can be displayed directly. 
    This package also registers a 'knitr'-engine enabling 'Maxima' code chunks 
    to be written in 'RMarkdown' documents.
URL: https://rcst.github.io/rim/
BugReports: https://github.com/rcst/rim/issues
SystemRequirements: Maxima (https://sourceforge.net/projects/maxima/,
        tested with versions 5.42.0 - 5.46.0), needs to be on PATH
License: GPL (>= 3)
Imports: methods, Rcpp, R6, knitr, GlobalOptions
LinkingTo: Rcpp
RoxygenNote: 7.2.3
Suggests: testthat (>= 3.0.0), rmarkdown
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2023-08-24 11:33:13 UTC; eric
Author: Eric Stemmler [aut, cre],
  Kseniia Shumelchyk [aut],
  Hans W. Borchers [aut]
Maintainer: Eric Stemmler <stemmler.eric@gmail.com>
Repository: CRAN
Date/Publication: 2023-08-24 12:00:02 UTC
Built: R 4.4.1; x86_64-apple-darwin24.0.0; 2024-09-27 22:41:04 UTC; unix
